@@ -3,7 +3,6 @@
 
 #include <lttoolbox/alphabet.h>
 #include <lttoolbox/input_file.h>
-#include <lttoolbox/my_stdio.h>
 #include <lttoolbox/state.h>
 #include <lttoolbox/trans_exe.h>
 #include <unicode/ustdio.h>
@@ -22,6 +21,7 @@ private:
   bool null_flush = true;
   bool dictionary_case = false;
   bool repeat_rules = false;
+  bool postgen = false;
   bool at_end = false;
   bool at_null = false;
 
@@ -37,6 +37,7 @@ private:
   int word_boundary_ns;
   int any_char;
   int any_tag;
+  int reading_boundary;
 public:
   LSXProcessor();
   void load(FILE* input);
@@ -53,6 +54,16 @@ public:
   {
     repeat_rules = val;
   }
+  void setPostgenMode(bool val)
+  {
+    postgen = val;
+    // this could potentially cause problems at some point...
+    if (val) {
+      escaped_chars.erase('/');
+    } else {
+      escaped_chars.insert('/');
+    }
+  }
 };
 
 #endif
